.. _package-summary:

Reference
-----------------------------

``dhlab`` subpackages
~~~~~~~~~~~~~~~~~~~~~~


.. autosummary::
   :recursive:
   :toctree: generated

   api
   text
   metadata
   ngram
   images
   utils


``dhlab`` legacy functionality
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. epigraph::

   If you are using older notebooks, the modules listed below are still
   available as imports directly from ``dhlab``:

   .. code-block:: python

      from dhlab import ...


.. currentmodule:: legacy

.. autosummary::
   :nosignatures:
   :toctree: generated

   nbtext
   graph_networkx_louvain
   token_map
   nbpictures
   module_update
   nb_external_files
